@@ -45,6 +45,8 @@ __all__ = (
     "ServiceUpdatedWaiterName",
     "TemplateVersionStatusType",
     "ServiceName",
+    "PaginatorName",
+    "WaiterName",
 )
 
 
@@ -370,10 +372,12 @@ ServiceName = Literal[
     "transcribe",
     "transfer",
     "translate",
+    "voice-id",
     "waf",
     "waf-regional",
     "wafv2",
     "wellarchitected",
+    "wisdom",
     "workdocs",
     "worklink",
     "workmail",
@@ -381,3 +385,24 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+PaginatorName = Literal[
+    "list_environment_account_connections",
+    "list_environment_template_versions",
+    "list_environment_templates",
+    "list_environments",
+    "list_service_instances",
+    "list_service_template_versions",
+    "list_service_templates",
+    "list_services",
+    "list_tags_for_resource",
+]
+WaiterName = Literal[
+    "environment_deployed",
+    "environment_template_version_registered",
+    "service_created",
+    "service_deleted",
+    "service_instance_deployed",
+    "service_pipeline_deployed",
+    "service_template_version_registered",
+    "service_updated",
+]
